@@ -17,6 +17,8 @@ public:
     friend const QDBusArgument &operator>>(const QDBusArgument &arg, DockRect &rect);
     friend QDBusArgument &operator<<(QDBusArgument &arg, const DockRect &rect);
 
+    bool operator ==(const DockRect& rect) const;
+    bool operator !=(const DockRect& rect) { return !operator==(rect); }
 private:
     int x;
     int y;
