@@ -15,7 +15,7 @@ struct TouchscreenInfo {
     QString deviceNode;
     QString serialNumber;
 
-    bool operator ==(const TouchscreenInfo& info);
+    bool operator ==(const TouchscreenInfo& info) const;
 };
 
 typedef QList<TouchscreenInfo> TouchscreenInfoList;
