@@ -98,10 +98,9 @@ public:
 
     bool checkAuthorization(const QString &actionId, const QString &service,const QDBusConnection &connection) const
     {
-        auto pid = connection.interface()->servicePid(service).value();
         auto authority = PolkitQt1::Authority::instance();
         auto result = authority->checkAuthorizationSync(actionId,
-                                                        PolkitQt1::UnixProcessSubject(pid),
+                                                        PolkitQt1::SystemBusNameSubject(service),
                                                         PolkitQt1::Authority::AllowUserInteraction);
         if (authority->hasError()) {
             qWarning() << "checkAuthorizationSync failed:" << authority->lastError()
@@ -327,15 +326,20 @@ public:
         QVariant var;
         for (int i = 0; i != met.parameterCount(); ++i)
         {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            auto type = met.parameterMetaType(i);
+            if(!type.isValid())
+#else
             int type = met.parameterType(i);
-            void *arg = arguments[i + 1];
-
-            if(type == QMetaType::UnknownType)
+            if (type == QMetaType::UnknownType)
+#endif
             {
                 qInfo() << "未知类型，不作处理 !";
                 return;
             }
 
+            void *arg = arguments[i + 1];
+
             var = QVariant(type, arg);
             argumentsList << var;
         }
