@@ -17,12 +17,12 @@ public:
     }
     virtual DDBusExtendedAbstractInterface *initConnect()
     {
-        m_dbusProxy = new org::deepin::dde::Timedate1(m_dbusName, m_dbusPath, QDBusConnection::sessionBus(), this);
+        m_dbusProxy = new __Session_Timedate1(m_dbusName, m_dbusPath, QDBusConnection::sessionBus(), this);
         return m_dbusProxy;
     }
     
 private:
-    org::deepin::dde::Timedate1 *m_dbusProxy;
+    __Session_Timedate1 *m_dbusProxy;
 };
 
 
