@@ -15,15 +15,19 @@ public:
     {
         InitFilterProperies(QStringList({}));
         InitFilterMethods(QStringList({"GetConfig"}));
+        QMap<QString, QString> auth;
+        auth["SetBacklightBrightness"] = "org.deepin.dde.api.proxy";
+        auth["SetConfig"] = "org.deepin.dde.api.proxy";
+        InitCheckAuthorization(auth);
         ServiceStart();
     }
     virtual DDBusExtendedAbstractInterface *initConnect()
     {
-        m_dbusProxy = new org::deepin::dde::Display1(m_dbusName, m_dbusPath, QDBusConnection::systemBus(), this);
+        m_dbusProxy = new __System_Display1(m_dbusName, m_dbusPath, QDBusConnection::systemBus(), this);
         return m_dbusProxy;
     }
 private:
-    org::deepin::dde::Display1 *m_dbusProxy;
+    __System_Display1 *m_dbusProxy;
 };
 
 
