@@ -13,15 +13,19 @@ public:
         QDBusConnection::BusType dbusType, QObject *parent = nullptr) 
         : DBusProxyBase(dbusName, dbusPath, dbusInterface, proxyDbusName, proxyDbusPath, proxyDbusInterface, dbusType, parent)
     {
+        QMap<QString, QString> auth;
+        auth["EnableDevice"] = "org.deepin.dde.api.proxy";
+        auth["ToggleWirelessEnabled"] = "org.deepin.dde.api.proxy";
+        InitCheckAuthorization(auth);
         ServiceStart();
     }
     virtual DDBusExtendedAbstractInterface *initConnect()
     {
-        m_dbusProxy = new org::deepin::dde::Network1(m_dbusName, m_dbusPath, QDBusConnection::systemBus(), this);
+        m_dbusProxy = new __System_Network1(m_dbusName, m_dbusPath, QDBusConnection::systemBus(), this);
         return m_dbusProxy;
     }
 private:
-    org::deepin::dde::Network1 *m_dbusProxy;
+    __System_Network1 *m_dbusProxy;
 };
 
 
